@@ -3,6 +3,6 @@ This module is a plugin that adds functionality for selecting data that has been
 "Acquisition Sequencer" in the PWS acquisition software.
 """
 
-from .plugin import AcquisitionSequencerPlugin
+from ._plugin import AcquisitionSequencerPlugin
 
 
